# These define which plugins are built as subpackages.  The gssapi definition
# also controls whether the plugin is even built.
# For RHL 7, gssapi = 0, md5 = 0, plain = 0.
# For RHL 7.1, gssapi = 1, md5 = 0, plain = 0.
# For RHL 7.2, gssapi = 1, md5 = 1, plain = 1.
%define gssapi 1
%define md5    0
%define plain  0

Summary: The Cyrus SASL library.
Name: cyrus-sasl
Version: 1.5.24
Release: 22.7
License: Freely Distributable
Group: System Environment/Libraries
Source: ftp://ftp.andrew.cmu.edu/pub/cyrus-mail/cyrus-sasl-%{version}.tar.gz
URL: http://asg.web.cmu.edu/sasl/sasl-library.html
Patch0: cyrus-sasl-1.5.21-des.patch
Patch1: cyrus-sasl-1.5.24-external.patch
Patch2: cyrus-sasl-1.5.24-syslog.patch
Patch3: cyrus-sasl-1.5.24-rpath.patch
Patch4: cyrus-sasl-1.5.24-autoconf.patch
Buildroot: %{_tmppath}/%{name}-root
BuildPrereq: gdbm-devel, krb5-devel, openssl-devel, pam-devel
Requires: pam
Prereq: /sbin/ldconfig

%description
The cyrus-sasl package contains the Cyrus implementation of SASL.
SASL is the Simple Authentication and Security Layer, a method for
adding authentication support to connection-based protocols.

%package devel
Requires: %{name} = %{version}-%{release}
Group: Development/Libraries
Summary: Files needed for developing applications with Cyrus SASL.

%description devel
The cyrus-sasl-devel package contains files needed for developing and
compiling applications which use the Cyrus SASL library.

%package gssapi
Requires: %{name} = %{version}-%{release}
Group: System Environment/Libraries
Summary: GSSAPI support for Cyrus SASL.

%description gssapi
The cyrus-sasl-gssapi package contains the Cyrus SASL plugins which
support GSSAPI authentication. GSSAPI is commonly used for Kerberos
authentication.

%package plain
Requires: %{name} = %{version}-%{release}
Group: System Environment/Libraries
Summary: PLAIN and LOGIN support for Cyrus SASL.

%description plain
The cyrus-sasl-plain package contains the Cyrus SASL plugins which support
PLAIN and LOGIN authentication schemes.

%package md5
Requires: %{name} = %{version}-%{release}
Group: System Environment/Libraries
Summary: CRAM-MD5 and DIGEST-MD5 support for Cyrus SASL.

%description md5
The cyrus-sasl-md5 package contains the Cyrus SASL plugins which support
CRAM-MD5 and DIGEST-MD5 authentication schemes.

%prep
%setup -q
%patch0 -p1 -b .des
%patch1 -p1 -b .external
%patch2 -p1 -b .syslog
%patch3 -p1 -b .rpath
%patch4 -p1 -b .autoconf
aclocal -I ./cmulocal
automake -a -c
autoconf

%build
CFLAGS="$RPM_OPT_FLAGS -fPIC"; export CFLAGS
%configure \
	--enable-static --enable-shared \
	--with-plugindir=%{_libdir}/sasl \
	--with-dblib=gdbm \
	--disable-krb4 \
%if %{gssapi}
	--enable-gssapi=/usr/kerberos \
%endif
	--with-rc4 \
	--enable-anon \
	--enable-cram \
	--enable-digest \
	--enable-plain \
	--enable-login
make

%install
rm -rf $RPM_BUILD_ROOT
%makeinstall
install -m755 -d $RPM_BUILD_ROOT%{_bindir}
./libtool --mode=install \
install -m755 sample/sample-client $RPM_BUILD_ROOT%{_bindir}/sasl-sample-client
./libtool --mode=install \
install -m755 sample/sample-server $RPM_BUILD_ROOT%{_bindir}/sasl-sample-server

%clean
rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README TODO doc/*.html doc/*.txt
%{_libdir}/libsasl*.so.*
%dir %{_libdir}/sasl/
%{_libdir}/sasl/*anonymous*.so*
%{_mandir}/man8/*
%{_sbindir}/saslpasswd
%{_sbindir}/sasldblistusers

%if %{plain}
%files plain
%defattr(-,root,root)
%endif
%{_libdir}/sasl/*plain*.so*
%{_libdir}/sasl/*login*.so*

%if %{md5}
%files md5
%defattr(-,root,root)
%endif
%{_libdir}/sasl/*crammd5*.so*
%{_libdir}/sasl/*digestmd5*.so*

%if %{gssapi}
%files gssapi
%defattr(-,root,root)
%{_libdir}/sasl/*gssapi*.so*
%endif

%files devel
%defattr(-,root,root)
%{_bindir}/sasl-sample-client
%{_bindir}/sasl-sample-server
%{_includedir}/*.h
%{_libdir}/libsasl*.*a
%{_libdir}/libsasl*.*so
%{_libdir}/sasl/*anonymous*.*a
%{_libdir}/sasl/*crammd5*.*a
%{_libdir}/sasl/*digestmd5*.*a
%{_libdir}/sasl/*gssapi*.*a
%{_libdir}/sasl/*login*.*a
%{_libdir}/sasl/*plain*.*a
%{_mandir}/man3/*

%changelog
* Fri Nov  2 2001 Nalin Dahyabhai <nalin@redhat.com> 1.5.24-22.7
- rebuild for RHL 7 and 7.1

* Fri Nov  2 2001 Nalin Dahyabhai <nalin@redhat.com> 1.5.24-23
- patch to fix possible syslog format-string vulnerability 

* Mon Oct 29 2001 Nalin Dahyabhai <nalin@redhat.com> 1.5.24-22
- add pam-devel as a buildprereq

* Wed Aug 29 2001 Nalin Dahyabhai <nalin@redhat.com> 1.5.24-21
- include sample programs in the -devel subpackage, prefixing their names
  with "sasl-" to reduce future potential naming conflicts

* Tue Aug 14 2001 Nalin Dahyabhai <nalin@redhat.com> 1.5.24-20
- build without -ggdb

* Fri Aug  3 2001 Nalin Dahyabhai <nalin@redhat.com>
- add gdbm-devel as a build dependency (#44990)
- split off CRAM-MD5 and DIGEST-MD5 into a subpackage of their own (#43079,
  and dialogs with David L. Parsley)

* Fri Apr 27 2001 Nalin Dahyabhai <nalin@redhat.com>
- split out the PLAIN and LOGIN mechanisms into their own package (this allows
  an administrator to disable them by simply removing the package)

* Fri Jan 19 2001 Nalin Dahyabhai <nalin@redhat.com>
- rebuild in new environment

* Wed Dec  6 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix gssapi-over-tls

* Fri Oct 27 2000 Nalin Dahyabhai <nalin@redhat.com>
- enable static libraries, but always build with -fPIC

* Wed Oct 25 2000 Nalin Dahyabhai <nalin@redhat.com>
- make sure the version of 1.5.24 in the package matches the masters (#18968)

* Mon Oct  9 2000 Nalin Dahyabhai <nalin@redhat.com>
- re-add the libsasl.so symlink to the -devel package (oops)

* Fri Oct  6 2000 Nalin Dahyabhai <nalin@redhat.com>
- move .so files for modules to their respective packages -- they're not -devel
  links meant for use by ld anyway

* Thu Oct  5 2000 Nalin Dahyabhai <nalin@redhat.com>
- split off -devel subpackage
- add a -gssapi subpackage for the gssapi plugins

* Wed Aug 16 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix the summary text

* Sun Aug 13 2000 Nalin Dahyabhai <nalin@redhat.com>
- re-enable arcfour and CRAM

* Fri Aug  4 2000 Nalin Dahyabhai <nalin@redhat.com>
- force use of gdbm for database files to avoid DB migration weirdness
- enable login mechanism
- disable gssapi until it can coexist peacefully with non-gssapi setups
- actually do a make in the build section (#15410)

* Fri Jul 21 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to 1.5.24

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Tue Jun 27 2000 Nalin Dahyabhai <nalin@redhat.com>
- rebuild in new environment (release 3)

* Mon Jun 19 2000 Nalin Dahyabhai <nalin@redhat.com>
- don't muck with syslogd in post
- remove patch for db-3.0 wackiness, no longer needed

* Thu Jun  8 2000 Nalin Dahyabhai <nalin@redhat.com>
- FHS cleanup
- don't strip anything by default

* Fri Feb 11 2000 Tim Powers <timp@redhat.com>
- fixed man pages not being gzipped

* Tue Nov 16 1999 Tim Powers <timp@redhat.com>
- incorporated changes from Mads Kiilerich
- release number is 1, not mk1

* Tue Nov 10 1999 Mads Kiilerich <mads@kiilerich.com>
- updated to sasl 1.5.11
- configure --disable-krb4 --without-rc4 --disable-cram 
  because of missing libraries and pine having cram as default...
- handle changing libsasl.so versions

* Mon Aug 30 1999 Tim Powers <timp@redhat.com>
- changed group

* Fri Aug 13 1999 Tim Powers <timp@redhat.com>
- first build for Powertools
